On 4/30/2019 8:26 PM, Jonathan Neuschäfer wrote:
"sysfs" was misspelled in a comment and a log message.

Signed-off-by: Jonathan Neuschäfer <j.neuschae...@gmx.net>
Reviewed-by: Mukesh Ojha <mo...@codeaurora.org>

Cheers,
-Mukesh
---
  drivers/base/firmware_loader/fallback.c | 6 +++---
  1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/base/firmware_loader/fallback.c 
b/drivers/base/firmware_loader/fallback.c
index b5c865fe263b..f962488546b6 100644
--- a/drivers/base/firmware_loader/fallback.c
+++ b/drivers/base/firmware_loader/fallback.c
@@ -674,8 +674,8 @@ static bool fw_run_sysfs_fallback(enum fw_opt opt_flags)
   *
   * This function is called if direct lookup for the firmware failed, it 
enables
   * a fallback mechanism through userspace by exposing a sysfs loading
  * interface. Userspace is in charge of loading the firmware through the syfs
  * loading interface. This syfs fallback mechanism may be disabled completely
   * on a system by setting the proc sysctl value ignore_sysfs_fallback to true.
   * If this false we check if the internal API caller set the 
@FW_OPT_NOFALLBACK
   * flag, if so it would also disable the fallback mechanism. A system may want
@@ -693,7 +693,7 @@ int firmware_fallback_sysfs(struct firmware *fw, const char 
*name,
                return ret;

        if (!(opt_flags & FW_OPT_NO_WARN))
-               dev_warn(device, "Falling back to syfs fallback for: %s\n",
+               dev_warn(device, "Falling back to sysfs fallback for: %s\n",
                                 name);
        else
                dev_dbg(device, "Falling back to sysfs fallback for: %s\n",
@@ -674,8 +674,8 @@ static bool fw_run_sysfs_fallback(enum fw_opt opt_flags)
enables
   * a fallback mechanism through userspace by exposing a sysfs loading
- * interface. Userspace is in charge of loading the firmware through the syfs
- * loading interface. This syfs fallback mechanism may be disabled completely
+ * interface. Userspace is in charge of loading the firmware through the sysfs
+ * loading interface. This sysfs fallback mechanism may be disabled completely
   * on a system by setting the proc sysctl value ignore_sysfs_fallback to true.
   * If this false we check if the internal API caller set the 
--
2.20.1

Reply via email to